# grafana_api [![Travis](https://img.shields.io/travis/m0nhawk/grafana_api.svg?style=flat-square)](https://travis-ci.org/m0nhawk/grafana_api)
[![GitHub issues](https://img.shields.io/github/issues/m0nhawk/grafana_api.svg?style=flat-square)](https://github.com/m0nhawk/grafana_api/issues) [![GitHub forks](https://img.shields.io/github/forks/m0nhawk/grafana_api.svg?style=flat-square)](https://github.com/m0nhawk/grafana_api/network) [![GitHub stars](https://img.shields.io/github/stars/m0nhawk/grafana_api.svg?style=flat-square)](https://github.com/m0nhawk/grafana_api/stargazers) [![GitHub license](https://img.shields.io/github/license/m0nhawk/grafana_api.svg?style=flat-square)](https://github.com/m0nhawk/grafana_api/blob/master/LICENSE)

[![PyPI](https://img.shields.io/pypi/v/grafana_api.svg?style=flat-square)](https://pypi.org/project/grafana-api/) [![PyPI](https://img.shields.io/pypi/wheel/grafana_api.svg?style=flat-square)](https://pypi.org/project/grafana-api/) [![PyPI](https://img.shields.io/pypi/pyversions/grafana_api.svg?style=flat-square)](https://pypi.org/project/grafana-api/) [![PyPI](https://img.shields.io/pypi/status/grafana_api.svg?style=flat-square)](https://pypi.org/project/grafana-api/)


## What is this library for?

Yet another Grafana API library for Python. Support both 2 and 3 Python versions.

## Requirements

You need either 2nd or 3rd version of Python and only the `requests` library installed.

## Quick start

It's available in PyPi repository:

    pip install -U grafana_api

## Status of REST API realization [![Coverage Status](https://coveralls.io/repos/github/m0nhawk/grafana_api/badge.svg?branch=master)](https://coveralls.io/github/m0nhawk/grafana_api?branch=master)

Work on API implementation still in progress.

| API | Status |
|---|---|
| Authentication | - |
| Dashboard | + |
| Dashboard Versions | - |
| Dashboard Permissions | - |
| Folder | - |
| Folder Permissions | - |
| Folder/Dashboard Search | - |
| Data Source | + |
| Organisation | + |
| Snapshot | - |
| Annotations | - |
| Alerting | - |
| User | + |
| Admin | +- |
| Preferences | + |
| Other | - |

## Issue tracker

Please report any bugs and enhancement ideas using the `grafana_api` issue tracker:

  https://github.com/m0nhawk/grafana_api/issues

Feel free to also ask questions on the tracker.

## License

`grafana_api` is licensed under the terms of the MIT License (see the file
[LICENSE](LICENSE)).
